## v0.5.0rc8 (2024-06-03)

### Fix

- OrderedEnum is not ordering according to enum position

## v0.5.0rc6 (2024-05-29)

### Feat

- Add DictObject class to custom collections package

## v0.5.0rc4 (2024-05-29)

### Feat

- Add DictObject class for accessing dictionary values as attributes

## v0.5.0rc2 (2024-05-23)

### Feat

- Add custom collections package

## v0.5.0a1 (2024-05-22)

### Feat

- Update build_quality test command and environment in CI workflow
- Add database model management tools
- Add api management tools
- Enforce config attributes type and allow async CLI execute methods

## v0.4.3 (2024-05-01)

### Fix

- Update CLI argument help message in ConfigAttr class to show required and env_var
- Update .gitignore and pyproject.toml

### Refactor

- Remove parse_args and include load method to ConfigEntity

## v0.4.2 (2024-05-01)

## v0.4.2rc1 (2024-05-01)

## v0.4.2a1 (2024-05-01)

### Fix

- Update README.md: Remove empty lines

## v0.4.1 (2024-05-01)

## v0.4.1rc5 (2024-05-01)

## v0.4.1rc4 (2024-05-01)

## v0.4.1rc2 (2024-05-01)

## v0.4.1a2 (2024-05-01)

### Fix

- Update workflow names to reflect their purpose
- Update changelog_increment_filename to "body.md" in main_pre_release.yml and main_release.yml workflows

## v0.4.0 (2024-05-01)

### Fix

- Update license format

## v0.3.0 (2024-05-01)

### Fix

- Update github actions versions
- Merge branch 'main' of github.com:kaeus-sgarcia/kframe
- Merge branch 'main' of github.com:kaeus-sgarcia/kframe
- Fix development, qa, and main branches CI/CD
- Merge branch 'main' of github.com:kaeus-sgarcia/kframe

## v0.2.2 (2024-04-30)

### Fix

- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD

## v0.2.1 (2024-04-30)

### Fix

- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD

## v0.2.0 (2024-04-30)

### Feat

- Initial project structure and cicd action

### Fix

- Fix development, qa, and main branches CI/CD
- Merge branch 'development' of github.com:kaeus-sgarcia/kframe into development
- Fix development, qa, and main branches CI/CD
- Merge branch 'development' of github.com:kaeus-sgarcia/kframe into development
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Merge branch 'development' of github.com:kaeus-sgarcia/kframe into development
- Fix CI/CD for quality brach
- Merge branch 'development' of github.com:kaeus-sgarcia/kframe into development
- Fix development, qa, and main branches CI/CD
- Fix development brack CI
- Fix cicd for development and quality branches
- Fix cicd for development branch

## v0.1.0 (2024-04-30)

### Feat

- First commit
